/**
 * @fileoverview 使用 G.Group 的组件
 * @author dxq613@gmail.com
 */
import { IElement, IGroup } from '@antv/g-base/lib/interfaces';
import { BBox, GroupComponentCfg, Point } from '../types';
import Component from './component';
declare type Callback = (evt: object) => void;
declare abstract class GroupComponent<T extends GroupComponentCfg = GroupComponentCfg> extends Component {
    getDefaultCfg(): {
        container: any;
        /**
         * @private
         * 缓存图形的 Map
         */
        shapesMap: {};
        group: any;
        capture: boolean;
        /**
         * @private 组件或者图形是否
         * @type {false}
         */
        isRegister: boolean;
        id: string;
        name: string; /**
         * @private
         * 缓存图形的 Map
         */
        type: string;
        locationType: string;
        offsetX: number;
        offsetY: number;
        animate: boolean;
        animateCfg: {
            duration: number;
            easing: string;
        };
        events: any;
        defaultCfg: {};
        visible: boolean;
    };
    remove(): void;
    clear(): void;
    getElementById(id: any): any;
    getContainer(): IGroup;
    update(cfg: Partial<T>): void;
    render(): void;
    show(): void;
    hide(): void;
    destroy(): void;
    getBBox(): BBox;
    on(evt: string, callback: Callback, once?: boolean): this;
    off(evt?: string, callback?: Callback): this;
    emit(eventName: string, eventObject: object): void;
    protected createOffScreenGroup(): any;
    protected getElementByLocalId(localId: any): any;
    protected applyOffset(): void;
    protected init(): void;
    protected initGroup(): void;
    /**
     * @protected
     * 在组件上添加分组，主要解决 isReigeter 的问题
     * @param {IGroup} parent 父元素
     * @param {object} cfg    分组的配置项
     */
    protected addGroup(parent: IGroup, cfg: any): IGroup;
    /**
     * @protected
     * 在组件上添加图形，主要解决 isReigeter 的问题
     * @param {IGroup} parent 父元素
     * @param {object} cfg    分组的配置项
     */
    protected addShape(parent: IGroup, cfg: any): import("@antv/g-base/lib/interfaces").IShape;
    protected initEvent(): void;
    protected removeEvent(): void;
    protected getElementId(localId: any): string;
    protected registerElement(element: any): void;
    protected unregisterElement(element: any): void;
    protected moveElementTo(element: IElement, point: Point): void;
    /**
     * 内部的渲染
     * @param {IGroup} group 图形分组
     */
    protected abstract renderInner(group: any): any;
    /**
     * 图形元素新出现时的动画，默认图形从透明度 0 到当前透明度
     * @protected
     * @param {string} elmentName 图形元素名称
     * @param {IElement} newElement  新的图形元素
     * @param {object} animateCfg 动画的配置项
     */
    protected addAnimation(elmentName: any, newElement: any, animateCfg: any): void;
    /**
     * 图形元素新出现时的动画，默认图形从透明度 0 到当前透明度
     * @protected
     * @param {string} elmentName 图形元素名称
     * @param {IElement} originElement 要删除的图形元素
     * @param {object} animateCfg 动画的配置项
     */
    protected removeAnimation(elementName: any, originElement: any, animateCfg: any): void;
    /**
     * 图形元素的更新动画
     * @param {string} elmentName 图形元素名称
     * @param {IElement} originElement 现有的图形元素
     * @param {object} newAttrs  新的图形元素
     * @param {object} animateCfg 动画的配置项
     */
    protected updateAnimation(elementName: any, originElement: any, newAttrs: any, animateCfg: any): void;
    protected updateElements(newGroup: any, originGroup: any): void;
    protected clearUpdateStatus(group: IGroup): void;
    private getDelegateObject;
    private appendDelegateObject;
    private getReplaceAttrs;
    private registerNewGroup;
    private deleteElements;
}
export default GroupComponent;
